@@ -3,7 +3,7 @@ package ObjectDB::Table;
 use strict;
 use warnings;
 
-our $VERSION = '3.12';
+our $VERSION = '3.13';
 
 use constant DEFAULT_PAGE_SIZE => 10;
 
@@ -82,12 +82,15 @@ sub find {
 
     my $columns = filter_columns([$self->meta->columns], $params);
 
+    my $join = $with->to_joins;
+    push @$join, @{$params->{join}} if $params->{join};
+
     my $select = SQL::Composer->build(
         'select',
         driver     => $self->dbh->{Driver}->{Name},
         from       => $self->meta->table,
         columns    => $columns,
-        join       => $with->to_joins,
+        join       => $join,
         where      => $where,
         limit      => $params->{limit},
         offset     => $params->{offset},
